<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>בחירת יישום</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>יישומים מותקנים</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>פקודה בהתאמה אישית</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>שורת פקודה להפעלה:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>שם יישום:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;ניתן להשתמש בקודים המיוחדים האלה בשורת הפקודה:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: מייצג שם של קובץ אחד&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: מייצג שמות של מספר קבצים&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: מייצג כתובת מדויקת של הקובץ&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: מייצג מספר כתובות&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>להשאיר את חלון המסוף פתוח לאחר הפעלת פקודה</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>הפעלה במדמה מסוף</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>הגדרת היישום הנבחר כפעולת בררת המחדל לסוג קובץ זה</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>עריכת סימניות</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>הוספת &amp;פריט</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>ה&amp;סרת פריט</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>ניתן להשתמש בגרירה והשלכה כדי לסדר את הפריטים מחדש</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>הפעלת קובץ</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;פתיחה</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>הפ&amp;עלה</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>הפעלה ב&amp;מסוף</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="99"/>
        <source>Remember for next files of this kind</source>
        <translation>לזכור לקבצים הבאים מהסוג הזה</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>פתחה:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>שם קובץ:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>סוג קובץ:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>יעד:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>עיבוד:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>בהכנה…</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>תהליך</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>הזמן שנותר:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>קבצים שעברו עיבוד:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>מאפייני קובץ</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>כללי</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>מיקום:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>סוג קובץ:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>סוג MIME:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>גודל קובץ:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>גודל בכונן:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>שינוי אחרון:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>יעד קישור:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>פתיחה עם:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>גישה אחרונה:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>יצירה:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>תכולה:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>סמל:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>בחירת סמל</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>הסרת סמל</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Device Usage:</source>
        <translation>ניצול מהמכשיר:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>הרשאות</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>בעלות</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="463"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>קבוצה:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="476"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>בעלים:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>בקרת גישה</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>אחר:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>להפוך את הקובץ למורשה הרצה</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>קריאה</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>כתיבה</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>הרצה</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="742"/>
        <source>Sticky</source>
        <translation>דביק</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>SetUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>מצב מתקדם</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>התאמה אישית</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="263"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>נא לבחור יישום לפתיחת קבצי &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>תיקייה</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>קובץ ריק</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>התיקייה &quot;%1&quot; שצויינה אינה תקנית</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>בטעינה…</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;אין תת תיקיות&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="213"/>
        <source>Open in New T&amp;ab</source>
        <translation>פתיחה ב&amp;לשונית חדשה</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New Win&amp;dow</source>
        <translation>פתיחה ב&amp;חלון חדש</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="222"/>
        <source>Open in Termina&amp;l</source>
        <translation>פתיחה במ&amp;סוף</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>להעתיק לכאן</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>להעביר לכאן</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>יצירת קישור סמלי כאן</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>לא ניתן לגרור לכאן</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>סימנייה חדשה</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>נראה כי הקובץ ‚%1’ הוא למעשה רשומת שולחן עבודה.
מה ברצונך לעשות אתו?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>נראה כי קובץ הטקסט ‚%1’ הוא למעשה סקריפט שניתן להריץ.
מה ברצונך לעשות אתו?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>ניתן להריץ את הקובץ ‚%1’. להריץ אותו?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="105"/>
        <source>Go Back</source>
        <translation>חזרה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="106"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+שמאלה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="112"/>
        <source>Go Forward</source>
        <translation>קדימה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="113"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+ימינה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="120"/>
        <source>Reload</source>
        <translation>רענון</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="121"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="138"/>
        <source>Create Folder</source>
        <translation>יצירת תיקייה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="154"/>
        <source>Icon View</source>
        <translation>תצוגת סמלים</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="158"/>
        <source>Thumbnail View</source>
        <translation>תצוגת תמונות ממוזערות</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="162"/>
        <source>Compact View</source>
        <translation>תצוגה חסכונית</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="166"/>
        <source>Detailed List View</source>
        <translation>תצוגת פירוט</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="174"/>
        <source>Icon Sizes</source>
        <translation>גדלי סמלים</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="176"/>
        <source>Size of big icons:</source>
        <translation>גודל הסמלים הגדולים:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="183"/>
        <source>Size of small icons:</source>
        <translation>גודל הסמלים הקטנים:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="190"/>
        <source>Size of thumbnails:</source>
        <translation>גודל התמונות הממוזערות:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="206"/>
        <source>Show Hidden</source>
        <translation>הצגת מוסתרים</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="218"/>
        <source>Show Thumbnails</source>
        <translation>הצגת תמונות ממוזערות</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="223"/>
        <source>Show File Tooltips</source>
        <translation>הצגת עצות צצות לקבצים</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="230"/>
        <source>Smooth Scrolling</source>
        <translation>גלילה חלקה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="247"/>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="580"/>
        <location filename="../filedialog.cpp" line="975"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="580"/>
        <source>Please select a file</source>
        <translation>נא לבחור בקובץ</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="622"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 כבר קיים.
להחליף אותו?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="945"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>הנתיב „%1” לא קיים</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="959"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>„%1” אינה תיקייה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="965"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>„%1” אינו קובץ</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1117"/>
        <location filename="../filedialog.cpp" line="1225"/>
        <source>&amp;Open</source>
        <translation>&amp;פתיחה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1120"/>
        <location filename="../filedialog.cpp" line="1233"/>
        <source>&amp;Save</source>
        <translation>&amp;שמירה</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1127"/>
        <source>All Files (*)</source>
        <translation>כל הקבצים (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="138"/>
        <source>Open File</source>
        <translation>פתיחת קובץ</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Save File</source>
        <translation>שמירת קובץ</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> פיקסלים</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>פתיחה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>פתיחה עם…</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Many files</source>
        <translation>מגוון קבצים</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="354"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>לפתוח את הקובץ הזה בגודל %1?</numerusform>
            <numerusform>לפתוח את הקבצים האלה בגודל %1?</numerusform>
            <numerusform>לפתוח את הקבצים האלה בגודל %1?</numerusform>
            <numerusform>לפתוח את הקבצים האלה בגודל %1?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="118"/>
        <source>Other Applications</source>
        <translation>יישומים אחרים</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="125"/>
        <source>Create &amp;New</source>
        <translation>יצירת &amp;חדש</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="144"/>
        <source>&amp;Restore</source>
        <translation>&amp;שחזור</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="154"/>
        <source>Cut</source>
        <translation>גזירה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="158"/>
        <source>Copy</source>
        <translation>העתקה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="162"/>
        <source>Paste</source>
        <translation>הדבקה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="166"/>
        <location filename="../filemenu.cpp" line="481"/>
        <source>&amp;Move to Trash</source>
        <translation>העברה ל&amp;אשפה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="170"/>
        <source>Rename</source>
        <translation>שינוי שם</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Mount</source>
        <translation>עיגון</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="240"/>
        <source>Unmount</source>
        <translation>ניתוק</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Eject</source>
        <translation>שליפה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="275"/>
        <source>Extract to...</source>
        <translation>חילוץ אל…</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="283"/>
        <source>Extract Here</source>
        <translation>חילוץ לכאן</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="290"/>
        <source>Compress</source>
        <translation>דחיסה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="299"/>
        <source>Properties</source>
        <translation>מאפיינים</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="310"/>
        <source>Trust selected executables</source>
        <translation>מתן אמון בקובצי הפעלה נבחרים</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="311"/>
        <source>Trust this executable</source>
        <translation>מתן אמון בקובץ הפעלה זה</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="416"/>
        <source>Output</source>
        <translation>פלט</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="148"/>
        <location filename="../filemenu.cpp" line="481"/>
        <source>&amp;Delete</source>
        <translation>מחי&amp;קה</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>העברתם של חלק מהקבצים לאשפה אינה אפשרית כיוון שמערכת ההפעלה שתחתיהם אינה תומכת בפעולה זו.
למחוק אותם במקום?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>אישור</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>למחוק את הקובץ הנבחר?</numerusform>
            <numerusform>למחוק את הקבצים הנבחרים?</numerusform>
            <numerusform>למחוק את הקבצים הנבחרים?</numerusform>
            <numerusform>למחוק את הקבצים הנבחרים?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>להעביר את הפריט הנבחר לפח האשפה?</numerusform>
            <numerusform>להעביר את הפריטים הנבחרים לפח האשפה?</numerusform>
            <numerusform>להעביר את הפריטים הנבחרים לפח האשפה?</numerusform>
            <numerusform>להעביר את הפריטים הנבחרים לפח האשפה?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>העברת קבצים</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>הקבצים הבאים מועברים לתיקיית היעד:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>העתקת קבצים</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>הקבצים הבאים מועתקים לתיקיית היעד:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>השלכת קבצים לאשפה</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>הקבצים הבאים מועברים לסל האשפה:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>מחיקת קבצים</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>הקבצים הבאים נמחקים:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>יצירת קישורים סמליים</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>נוצרים קישורים סמליים לקבצים הבאים:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>שינוי מאפיינים</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>המאפיינים של הקבצים הבאים משתנים:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>שחזור קבצים מהאשפה</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>הקבצים הבאים משוחזרים מסל האשפה:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>צפייה בתוכן התיקייה</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>צפייה ועריכה של תוכן התיקייה</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>קריאה</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>קריאה וכתיבה</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>אין הרשאה</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>קבצים מסוגים שונים</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <location filename="../filepropsdialog.cpp" line="317"/>
        <location filename="../filepropsdialog.cpp" line="324"/>
        <source>N/A</source>
        <translation>לא זמין</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="328"/>
        <source>Multiple Files</source>
        <translation>מגוון קבצים</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="405"/>
        <source>%p% used</source>
        <translation>%p% מנוצלים</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="406"/>
        <source>%1 Free of %2</source>
        <translation>%1 פנויים מתוך %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="452"/>
        <source>no file</source>
        <translation>אין קובץ</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="454"/>
        <source>one file</source>
        <translation>קובץ אחד</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="456"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>קובץ %Ln</numerusform>
            <numerusform>%Ln קבצים</numerusform>
            <numerusform>%Ln קבצים</numerusform>
            <numerusform>%Ln קבצים</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="490"/>
        <location filename="../filepropsdialog.cpp" line="535"/>
        <source>Select an icon</source>
        <translation>נא לבחור סמל</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="492"/>
        <location filename="../filepropsdialog.cpp" line="537"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>תמונות ‎(*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="643"/>
        <source>Apply changes</source>
        <translation>החלת השינויים</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="644"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>להחיל את השינויים האלה רקורסיבית על כל הקבצים ותת־התיקיות?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="152"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="152"/>
        <source>You should add at least one directory to search.</source>
        <translation>עליך להוסיף לפחות תיקייה אחת לחיפוש.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="159"/>
        <source>Select a folder</source>
        <translation>נא לבחור תיקייה</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="479"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>לא ניתן להעתיק תיקייה לתוך עצמה!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="530"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>לא ניתן ליצור קישור על מערכת קישור בלתי טבעית</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="57"/>
        <source>Empty Trash</source>
        <translation>פינוי האשפה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Create &amp;New</source>
        <translation>יצירת &amp;חדשה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="74"/>
        <source>&amp;Paste</source>
        <translation>ה&amp;דבקה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="87"/>
        <source>Select &amp;All</source>
        <translation>בחירת ה&amp;כול</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="91"/>
        <source>Invert Selection</source>
        <translation>היפוך הבחירה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="98"/>
        <source>Sorting</source>
        <translation>סידור</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="103"/>
        <source>Show Hidden</source>
        <translation>הצגת מוסתרים</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="138"/>
        <source>Folder Pr&amp;operties</source>
        <translation>מאפייני &amp;תיקייה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="181"/>
        <source>Output</source>
        <translation>פלט</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="203"/>
        <source>By File Name</source>
        <translation>לפי שם קובץ</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="204"/>
        <source>By Modification Time</source>
        <translation>לפי מועד שינוי</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By Creation Time</source>
        <translation>לפי מועד היצירה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="208"/>
        <source>By Deletion Time</source>
        <translation>לפי מועד מחיקה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="211"/>
        <source>By File Size</source>
        <translation>לפי גודל קובץ</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="212"/>
        <source>By File Type</source>
        <translation>לפי סוג קובץ</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Owner</source>
        <translation>לפי בעלות על קובץ</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Group</source>
        <translation>לפי קבוצת הקובץ</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="220"/>
        <source>Ascending</source>
        <translation>עולה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="225"/>
        <source>Descending</source>
        <translation>יורד</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="242"/>
        <source>Folder First</source>
        <translation>תיקיות בהתחלה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="250"/>
        <source>Hidden Last</source>
        <translation>הוסתר לאחרונה</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="258"/>
        <source>Case Sensitive</source>
        <translation>תלוי רישיות</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="304"/>
        <source>Location:</source>
        <translation>מיקום:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="308"/>
        <source>File type:</source>
        <translation>סוג קובץ:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="313"/>
        <source>File size:</source>
        <translation>גודל קובץ:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="317"/>
        <source>Last modified:</source>
        <translation>שינוי אחרון:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="318"/>
        <source>Last accessed:</source>
        <translation>גישה אחרונה:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>N/A</source>
        <translation>לא זמין</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>Created:</source>
        <translation>יצירה:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="326"/>
        <source>Owner:</source>
        <translation>בעלות:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="327"/>
        <source>Group:</source>
        <translation>קבוצה:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="394"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="397"/>
        <source>Type</source>
        <translation>סוג</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="400"/>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="403"/>
        <source>Modified</source>
        <translation>מועד שינוי</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="406"/>
        <source>Created</source>
        <translation>יצירה</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="409"/>
        <source>Deleted</source>
        <translation>נמחקה</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="412"/>
        <source>Owner</source>
        <translation>בעלות</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="415"/>
        <source>Group</source>
        <translation>קבוצה</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="405"/>
        <source>Auto-resize columns</source>
        <translation>שינוי גודל עמודות אוטומטית</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="422"/>
        <source>Visible Columns</source>
        <translation>עמודות גלויות</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>מודגש</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>נטוי</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>הת&amp;חברות</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="130"/>
        <source>&amp;Edit Path</source>
        <translation>ע&amp;ריכת נתיב</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="133"/>
        <source>&amp;Copy Path</source>
        <translation>ה&amp;עתקת נתיב</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="47"/>
        <source>Places</source>
        <translation>מקומות</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="55"/>
        <source>Desktop</source>
        <translation>שולחן עבודה</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="61"/>
        <source>Computer</source>
        <translation>מחשב</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="69"/>
        <source>Applications</source>
        <translation>יישומים</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="78"/>
        <source>Network</source>
        <translation>רשת</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Devices</source>
        <translation>התקנים</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="137"/>
        <source>Bookmarks</source>
        <translation>סימניות</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="228"/>
        <source>Trash</source>
        <translation>אשפה</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="482"/>
        <source>Open in New Tab</source>
        <translation>פתיחה בלשונית חדשה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="485"/>
        <source>Open in New Window</source>
        <translation>פתיחה בחלון חדש</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="497"/>
        <source>Empty Trash</source>
        <translation>פינוי האשפה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="517"/>
        <location filename="../placesview.cpp" line="579"/>
        <source>Hide</source>
        <translation>הסתרה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="534"/>
        <source>Move Bookmark Up</source>
        <translation>העברת הסימנייה למעלה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="541"/>
        <source>Move Bookmark Down</source>
        <translation>העברת הסימנייה למטה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="546"/>
        <source>Rename Bookmark</source>
        <translation>שינוי שם לסימנייה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="550"/>
        <source>Remove Bookmark</source>
        <translation>הסרת סימנייה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="560"/>
        <location filename="../placesview.cpp" line="593"/>
        <source>Unmount</source>
        <translation>ניתוק עיגון</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="564"/>
        <source>Mount</source>
        <translation>עיגון</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="570"/>
        <source>Eject</source>
        <translation>שליפה</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="605"/>
        <source>Show All Entries</source>
        <translation>הצגת כל הרשומות</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>סוג: %1
גודל: %2
שינוי: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>סוג: %1
שינוי: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;שכתוב</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>שי&amp;נוי שם</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="108"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;לקובץ אין אפשרות לשכתב את עצמו.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;נא לבחור שם אחר.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>רשימות</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>עץ תיקיות</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>לא ניתן להוציא את &quot;%s%&quot; מהאשפה: הנתיב המקורי לא ידוע</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>עיגון</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>התחברות &amp;אלמונית</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>התחברות בתור מ&amp;שתמש:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>שם &amp;משתמש:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;ססמה:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>שם מת&amp;חם:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>לש&amp;כוח את הססמה מיידית</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation>שמירת הסיסמה עבור הסשן &amp;הזה בזיכרון</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>ל&amp;זכור לתמיד</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="163"/>
        <source>Rename File</source>
        <translation>שינוי שם קובץ</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Please enter a new name:</source>
        <translation>נא להקליד שם חדש:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="669"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="147"/>
        <location filename="../utilities.cpp" line="286"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="223"/>
        <source>Create Folder</source>
        <translation>יצירת תיקייה</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="224"/>
        <source>Create File</source>
        <translation>יצירת קובץ</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="228"/>
        <source>Please enter a new file name:</source>
        <translation>נא להקליד שם חדש לקובץ:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="229"/>
        <source>New text file</source>
        <translation>קובץ טקסט חדש</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="233"/>
        <source>Please enter a new folder name:</source>
        <translation>נא להקליד שם חדש לתיקייה:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="234"/>
        <source>New folder</source>
        <translation>תיקייה חדשה</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="239"/>
        <source>Enter a name for the new %1:</source>
        <translation>נא להקליד שם עבור %1 החדש:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="687"/>
        <source>Custom Icon Error</source>
        <translation>שגיאת סמל בהתאמה אישית</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>הנתיב אינו מעוגן.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>קובץ רשומת שולחן עבודה שגוי: ‚%1’</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>לא מוגדר יישום בררת מחדל להפעלת ‚%1’</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>לא ניתן להגדיר את תיקייה העבודה אל ‚%1’:‏ %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>מזהה: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>לא זמין</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>אישור להחלפת הקבצים</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;כבר קיים קובץ בשם הזה במיקום הזה.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;להחליף את הקובץ הקיים?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>עם הקובץ להלן?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>שם &amp;קובץ:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>יש להחיל אפשרות זו לכל הקבצים הקיימים</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>חיפוש קבצים</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>שם/מיקום</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>תבניות שמות קבצים:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>שימוש בביטויים רגולריים</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>מיקומים לחיפוש:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>הו&amp;ספה</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>הס&amp;רה</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>חיפוש אחר קבצים מוסתרים</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>סוג קובץ</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>לחפש קבצים מהסוגים הבאים בלבד:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>קובצי טקסט</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>קובצי תמונות</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>קובצי שמע</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>קובצי וידאו</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>מסמכים</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>תיקיות</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>תוכן</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>הקובץ מכיל:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>שימוש ב&amp;ביטויים רגולריים</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>מאפיינים</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>גודל קובץ:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <source>Larger than:</source>
        <translation>גדול מ־:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="316"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>בתים</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="321"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="326"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="331"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Smaller than:</source>
        <translation>קטן מ־:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>תלוי רישיות</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>חיפוש בתת־תיקיות</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>&amp;ללא תלות ברישיות</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>מועד השינוי האחרון:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>לפני:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="392"/>
        <source>Later than:</source>
        <translation>אחרי:</translation>
    </message>
</context>
</TS>
